Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(927)

Unified Diff: chrome/browser/chromeos/login/auth/user_context.h

Issue 296773002: Add a Key class (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Rebased. Created 6 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/login/auth/user_context.h
diff --git a/chrome/browser/chromeos/login/auth/user_context.h b/chrome/browser/chromeos/login/auth/user_context.h
index 8617ddc475b27d4e9f4524819545da20d12e4bc7..003576cc5aafb2b3131bab6df8db4efaf208cbbf 100644
--- a/chrome/browser/chromeos/login/auth/user_context.h
+++ b/chrome/browser/chromeos/login/auth/user_context.h
@@ -7,11 +7,13 @@
#include <string>
+#include "chrome/browser/chromeos/login/auth/key.h"
+
namespace chromeos {
// Information that is passed around while authentication is in progress. The
// credentials may consist of a |user_id|, |password| pair or a GAIA
// |auth_code|. The |user_id_hash| is used to locate the user's home directory
// mount point for the user. It is set when the mount has been completed.
class UserContext {
public:
@@ -31,11 +33,11 @@ class UserContext {
~UserContext();
bool operator==(const UserContext& context) const;
+ bool operator!=(const UserContext& context) const;
const std::string& GetUserID() const;
- const std::string& GetPassword() const;
- bool DoesNeedPasswordHashing() const;
- const std::string& GetKeyLabel() const;
+ const Key* GetKey() const;
+ Key* GetKey();
const std::string& GetAuthCode() const;
const std::string& GetUserIDHash() const;
bool IsUsingOAuth() const;
@@ -44,9 +46,7 @@ class UserContext {
bool HasCredentials() const;
void SetUserID(const std::string& user_id);
- void SetPassword(const std::string& password);
- void SetDoesNeedPasswordHashing(bool does_need_password_hashing);
- void SetKeyLabel(const std::string& key_label);
+ void SetKey(const Key& key);
void SetAuthCode(const std::string& auth_code);
void SetUserIDHash(const std::string& user_id_hash);
void SetIsUsingOAuth(bool is_using_oauth);
@@ -56,9 +56,7 @@ class UserContext {
private:
std::string user_id_;
- std::string password_;
- bool does_need_password_hashing_;
- std::string key_label_;
+ Key key_;
std::string auth_code_;
std::string user_id_hash_;
bool is_using_oauth_;
@@ -7,11 +7,13 @@
namespace chromeos {
// Information that is passed around while authentication is in progress. The
-// credentials may consist of a |user_id|, |password| pair or a GAIA
-// |auth_code|. The |user_id_hash| is used to locate the user's home directory
+// credentials may consist of a |user_id_|, |key_| pair or a GAIA |auth_code_|.
+// The |user_id_hash_| is used to locate the user's home directory
// mount point for the user. It is set when the mount has been completed.
class UserContext {

Powered by Google App Engine
This is Rietveld 408576698